@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2003 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //  
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of Common C++.
-// 
-// The exception is that, if you link the Common C++ library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.
 //
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-// 
-// This exception applies only to the code released under the 
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU 
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for Common C++, it is your choice
+//
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 /**
  * @file buffer.h
@@ -95,12 +92,14 @@ protected:
 	 * @param buf pointer to copy contents of head of buffer to.
 	 */
 	virtual size_t onPeek(void *buf) = 0;
+
 	/**
 	 * Invoke derived class object request from buffer.
 	 * @return size of object returned.
 	 * @param buf pointer to hold object returned from the buffer.
 	 */
 	virtual size_t onWait(void *buf) = 0;
+
 	/**
 	 * Invoke derived class posting of object to buffer.
 	 * @return size of object posted.
@@ -175,8 +174,7 @@ public:
 	 * New virtual to test if buffer is a valid object.
 	 * @return true if object is valid.
 	 */
-	virtual bool isValid(void)
-		{return true;};
+	virtual bool isValid(void);
 };
 
 /**
@@ -278,16 +276,14 @@ protected:
 	 * Start of dequeing.  Maybe we need to connect a database
 	 * or something, so we have a virtual...
 	 */
-	virtual void startQueue(void)
-		{return;};
+	virtual void startQueue(void);
 
 	/**
 	 * End of dequeing, we expect the queue is empty for now.  Maybe
 	 * we need to disconnect a database or something, so we have
 	 * another virtual.
 	 */
-	virtual void stopQueue(void)
-		{return;};
+	virtual void stopQueue(void);
 
 	/**
 	 * Virtual callback method to handle processing of a queued
