@@ -1684,7 +1684,7 @@ public:
  * @author David Sugar <dyfet@ostel.com>
  * @short Threaded streamable socket with non-blocking constructor.
  */
-class __EXPORT TCPSession : public TCPStream, public Thread
+class __EXPORT TCPSession : public Thread, public TCPStream
 {
 private:
 	TCPSession(const TCPSession &rhs); // not defined
@@ -1711,18 +1711,6 @@ protected:
 	 */
 	void initial(void);
 
-	/**
-	 * TCPSession derived objects can be freely created with "new"
-	 * and safely terminate their "run" method on their own by
-	 * self-deleting when the thread terminates.
-	 *
-	 * @note Since a thread cannot delete its own context or join
-	 * itself, to make a TCPSession that is a self running object
-	 * that self-deletes, one has to detach the associated thread
-	 * by using detach() instead of start().
-	 */
-	void final(void)
-		{delete this;};
 public:
 	/**
 	 * Create a TCP socket that will be connected to a remote TCP
@@ -1755,6 +1743,11 @@ public:
 #ifdef	CCXX_IPV6
 	TCPSession(TCPV6Socket &server, int pri = 0, size_t stack = 0);
 #endif
+
+	/**
+	 * Make sure destruction happens through a virtual...
+	 */
+	virtual ~TCPSession();
 };
 
 #if defined(WIN32)
