@@ -92,6 +92,10 @@ typedef DWORD   timeout_t;
 namespace ost {
 #endif
 
+#ifdef	HAVE_GCC_CXX_BITS_ATOMIC
+using namespace __gnu_cxx;
+#endif
+
 class __EXPORT Thread;
 class __EXPORT ThreadKey;
 
@@ -483,6 +487,11 @@ class __EXPORT AtomicCounter
 private:
 #ifdef	HAVE_ATOMIC_AIX
 	volatile int counter;
+#elif   HAVE_GCC_BITS_ATOMIC
+	volatile _Atomic_word counter;
+#elif   HAVE_GCC_CXX_BITS_ATOMIC
+	volatile _Atomic_word counter;
+//	__gnu_cxx::_Atomic_word counter;
 #elif	HAVE_ATOMIC
 	atomic_t atomic;
 #else
@@ -729,16 +738,16 @@ public:
 	void post(void);
 
 	// FIXME: how implement getValue for posix compatibility ?
+	// not portable...
+
+#if	0
 	/**
 	 * Get the current value of a semaphore.
 	 *
 	 * @return current value.
 	 */
-#ifndef WIN32
-#ifndef __CYGWIN32__
 	int getValue(void);
 #endif
-#endif
 };
 
 /**
