@@ -236,6 +236,37 @@ URLStream::Error URLStream::submit(const char *path, const char **vars, size_t b
 	}
 }
 
+URLStream::Error URLStream::post(const char *path, MIMEMultipartForm &form, size_t buf)
+{
+	Error status = errInvalid, saved;
+	if(!strnicmp(path, "http:", 5))
+	{
+		urlmethod = methodHttpPostMultipart;
+		path = strchr(path + 5, '/');
+		status = sendHTTPHeader(path, (const char **)form.getHeaders(), buf);
+	}
+
+	if(status == errInvalid || status == errTimeout)
+	{
+		if(Socket::state != AVAILABLE)
+			close();
+		return status;
+	}
+	saved = status;
+	status = getHTTPHeaders();
+	if(status == errSuccess)
+	{
+		form.body(dynamic_cast<std::ostream *>(this));
+		return saved;
+	}
+	if(status == errTimeout)
+	{
+		if(Socket::state != AVAILABLE)
+			close();
+	}
+	return status;
+}
+
 URLStream::Error URLStream::post(const char *path, const char **vars, size_t buf)
 {
 	Error status = errInvalid, saved;
@@ -253,19 +284,16 @@ URLStream::Error URLStream::post(const char *path, const char **vars, size_t buf
 			close();
 		return status;
 	}
-	else
+	saved = status;
+	status = getHTTPHeaders();
+	if(status == errSuccess)
+		return saved;
+	if(status == errTimeout)
 	{
-		saved = status;
-		status = getHTTPHeaders();
-		if(status == errSuccess)
-			return saved;
-		else if(status == errTimeout)
-		{
-			if(Socket::state != AVAILABLE)
-				close();
-		}
-		return status;
+		if(Socket::state != AVAILABLE)
+			close();
 	}
+	return status;
 }
 
 
@@ -373,6 +401,7 @@ URLStream::Error URLStream::get(const char *urlpath, size_t buf)
 		return errSuccess;
 	case methodHttpPut:
 	case methodHttpPost:
+	case methodHttpPostMultipart:
 	case methodFtpGet:
 	case methodFtpPut:
 	case methodFilePut:
@@ -539,6 +568,7 @@ retry:
 			str << uri;
 		break;
 	case methodHttpPost:
+	case methodHttpPostMultipart:
 		str << "POST ";
 		if(proxyPort)
 		{
@@ -633,23 +663,31 @@ retry:
 			str << *(add++) << "\r\n";
 		}
 	}
-	if(vars && urlmethod == methodHttpPost)
-	{
-		while(*args)
+	if(vars)
+		switch(urlmethod)
 		{
-			var = *args;
-			if(count++ || !strchr(var, '='))
-				len += strlen(var) + 1;
-			else
-				len = strlen(var);
-			++args;
+		case methodHttpPost:
+			while(*args)
+			{
+				var = *args;
+				if(count++ || !strchr(var, '='))
+					len += strlen(var) + 1;
+				else
+					len = strlen(var);
+				++args;
+			}
+			count = 0;
+			len += 2;
+			str << "Content-Type: application/x-www-form-urlencoded" << "\r\n";
+			str << "Content-Length: " << (unsigned)len << "\r\n";
+			break;
+		case methodHttpPostMultipart:
+			while(*args)
+				str << *(args++) << "\r\n";
+			break;
 		}
-		count = 0;
-		len += 2;
-		str << "Content-Length: " << (unsigned)len << "\r\n";
-	}
 
-        str << "\r\n";
+	str << "\r\n";
 #ifdef HAVE_SSTREAM
 	// sstream does not want ends
 #else
